@@ -5,19 +5,18 @@ from invenio_db import db
 from invenio_pidstore.models import PersistentIdentifier, PIDStatus
 from jsonref import requests
 
-from .json_schema_mapping import schema_mapping
-
+from .new_datasets_mapping import schema_mapping
 
 def doi_already_requested(record):
     doi_requested = False
 
-    if "identifiers" not in record:
+    if "persistentIdentifiers" not in record:
         return doi_requested
-    identifiers_array = record["identifiers"]
+    identifiers_array = record["persistentIdentifiers"]
 
 
     for id in identifiers_array:
-        if "status" in id and "doi" in id["scheme"] and "requested" in id["status"]:
+        if "DOI" in id["scheme"] and "requested" in id["status"]:
             doi_requested = True
             break
 
@@ -27,17 +26,17 @@ def doi_request(record):
 
     #if doi was not already requested
     if not doi_already_requested(record):
-        if "identifiers" not in record:
-            record['identifiers'] = [{
+        if "persistentIdentifiers" not in record:
+            record['persistentIdentifiers'] = [{
                 "identifier": "",
-                "scheme": "doi",
+                "scheme": "DOI",
                 "status": "requested"
             }]
         else:
-            record['identifiers'].append(
+            record['persistentIdentifiers'].append(
                 {
                     "identifier": "",
-                    "scheme": "doi",
+                    "scheme": "DOI",
                     "status": "requested"
                 }
             )
@@ -49,25 +48,26 @@ def doi_request(record):
 def doi_approved(record, pid_type, test_mode = False):
 
     if doi_already_requested(record):
-        record['identifiers'].remove(
+        record['persistentIdentifiers'].remove(
             {
                 "identifier": "",
-                "scheme": "doi",
+                "scheme": "DOI",
                 "status": "requested"
             }
         )
         data = schema_mapping(record, pid_type, test_mode=test_mode)
         doi = doi_registration(data=data, test_mode=test_mode)
         if doi != None:
-            record['identifiers'].append(
+            record['persistentIdentifiers'].append(
                 {
                     "identifier": doi,
-                    "scheme": "doi"
+                    "scheme": "DOI",
+                    "statuse": "registered"
                 }
             )
             record.commit()
 
-            PersistentIdentifier.create('doi', doi, object_type='rec',
+            PersistentIdentifier.create('DOI', doi, object_type='rec',
                                     object_uuid=record.id,
                                     status=PIDStatus.REGISTERED)
 
@@ -87,7 +87,7 @@ def doi_registration(data, test_mode = False):
 
 
     request = requests.post(url=url, json=data, headers = {'Content-type': 'application/vnd.api+json'}, auth=(username, password))
-
+    doi = ''
     if request.status_code == 201:
         response = json.loads(request.text)
         doi = response['data']['id']
